@@ -5,37 +5,38 @@ import os
 import inspect
 import string
 from qds_ops.tparty.knife import Knife
-from qds_ops.utils.fork import Fork
 from qds_ops.entities.rds import RDS
 import logging
 
 
 class Log(Tier):
-    ami_id = "ami-c6bd64ae"
-    region = "us-east-1"
-    instance_type = "m1.large"
-    run_list = '{"run_list":["recipe[webslave::logserver]"],"qubole_tier":"log"}'
-    security_groups = ["log-server"]
-    modules = []
-    port = 7777
 
+    def __init__(self):
+        tier = "log"
+        modules = ["hustler"]
+        ami = "ami-c6bd64ae"
+        region = "us-east-1"
+        instance_type = "m1.large"
+        run_list = '{"run_list":["recipe[webslave::logserver]"],"qubole_tier":"log"}'
+        security_groups = ["log-server"]
+        port = 7777
 
-    def __init__(self, subparser):
-        self.tier = "log"
-        self.modules = ["hustler"]
-        super(Log, self).__init__(subparser)
-        self._setup_parser()
+        super(Log, self).__init__(tier=tier, modules=modules, ami=ami,
+                                  region=region, instance_type=instance_type, run_list=run_list,
+                                  security_groups=security_groups, port=port
+                                  )
         self.knife = Knife()
+        self.is_autoscalable = False
 
-    def _setup_parser(self):
-        # create
+    def configure_parsers(self):
+        #create 
         create = self.tier_parser.add_parser("create", help="launches a new instance of log-server")
         create.add_argument("-d", "--dry-run", help="Dry Run: Dont really create the tier",
                             default=False, dest="dry_run", action="store_true")
         create.add_argument("-D", "--disable-termination", help="disable termination",
                             default=False, dest="disable_termination", action="store_true")
         create.add_argument("-a", "--ami-id", help="AMI ID to use for the log tier",
-                            default=self.ami_id, dest="ami_id")
+                            default=self.ami, dest="ami")
         create.add_argument("-r", "--region", help="Region where the tier will be located",
                             default=self.region, dest="region")
         create.add_argument("-i", "--instance-type", help="Instance Type of the machine",
@@ -74,14 +75,14 @@ class Log(Tier):
                 ec2_conn.close()
                 return
         reservation = ec2_conn.run_instances(
-            self.ami_id,
-            key_name=rows["value"],
-            instance_type=args.instance_type,
-            security_groups=self.security_groups,
-            user_data=user_data,
-            disable_api_termination=args.disable_termination,
-            dry_run=args.dry_run)
-
+            self.ami,
+            key_name = rows["value"],
+            instance_type = args.instance_type,
+            security_groups = self.security_groups,
+            user_data = user_data,
+            disable_api_termination = args.disable_termination,
+            dry_run = args.dry_run)
+        
         started_instance = reservation.instances[0]
         started_instance.add_tag("Name", self._tag(args.environment))
 
@@ -120,5 +121,3 @@ class Log(Tier):
             if tag in i.tags and i.tags[tag] == value:
                 matched_instances.append(i)
         return matched_instances
-
-
